OutSourceBuilder class

Constructors

OutSourceBuilder(List<Generator> generators, String partId)

Properties

allowSyntaxErrors bool
Whether to allow syntax errors in input libraries.
finalinherited
buildExtensions Map<String, List<String>>
Mapping from input file extension to output file extensions.
no setter
formatOutput String Function(String)
Function that determines how the generated code is formatted.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) Future
Generates the outputs for a given BuildStep.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited